@@ -146,7 +146,7 @@ public final class MALPollCreateTableTask extends AbstractCreateTableImpl implem
         LOG.info("UpdateTask 'MALPollCreateTableTask' successfully performed!");
     }
 
-    private void createTable(final String tablename, final String sqlCreate, final Connection con) throws OXException, OXException {
+    private void createTable(final String tablename, final String sqlCreate, final Connection con) throws OXException {
         PreparedStatement stmt = null;
         try {
             if (Tools.tableExists(con, tablename)) {
@@ -154,7 +154,7 @@ public final class MALPollCreateTableTask extends AbstractCreateTableImpl implem
             }
             stmt = con.prepareStatement(sqlCreate);
             stmt.executeUpdate();
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             closeSQLStuff(stmt);
